﻿' VB.NET to Attach User Data
'   lines starting with an apostrophe are comments
Public Class AttachUD

    ' create Visual CADD object
    Shared WithEvents vcadd As New VCadd32.Automation

    Public Shared Function Run(ByVal str As String) As Integer

        '   Set the required unique user data name in the application
        '   initialization routine:
        '       In order to setup user data for each entity and the 
        '       drawing header, a unique user data name must be 
        '       specified to reference the information.  The user 
        '       data name is case insensitive and can be up to 15 
        '       characters long.  The following code sets a user 
        '       data name of "MyData":

        vcadd.SetUserDataName("MyData")

        '   Attach the information to the current entity:
        '       To access user data in the current entity, call 
        '       VCSetEntityUserData.

        vcadd.SetEntityUserData()

        '     The current entity can be set in a number of ways 
        '     using any of the Visual CADD API parsing routines or 
        '     VCSetCurrentEntity.  For information see the topic 
        '     Parsing the Database.  For illustration, we will use 
        '     the first entity in the database with entity handle or 
        '     index 0.  The user data will be attached to this 
        '     current entity.

        vcadd.SetCurrentEntity(0)

        '   verify we have a current entity before proceeding
        If (vcadd.GetErrorCode() = 0) Then

            '   Add or set the desired user data values to the 
            '   current entity:
            '       The Visual CADD API allows two methods for 
            '       attaching the user data information.  The easiest
            '       method is to simply use the add routines which 
            '       adds the data to the next available slot in the 
            '       user data segment. The API also allows user data 
            '       to be set and placed at a specific index within 
            '       the user data.  The benefits of the second method 
            '       become apparent when working with multiple data 
            '       values being attached to the entity.  As more 
            '       data is attached, a hierarchical system can be 
            '       set up to access the information desired.  The 
            '       following code adds a user data short (0), 
            '       double (25.5), string ("My Application Data"), 
            '       and chunk to the current entity:

            vcadd.AddCurrentEntityUserDataShort(0)
            vcadd.AddCurrentEntityUserDataDouble(25.5)
            vcadd.AddCurrentEntityUserDataString("My Application Data")

            Dim bFlags As Byte() = {&H23, &HA3, &H6F, &H8E, &H66, &HFF, &HFF, &HB2}
            vcadd.AddCurrentEntityUserDataChunk(bFlags)

            '   Optional - if the current entity already has user 
            '   data and your application knows the order and kind of
            '   the data, then you can set or replace the existing 
            '   data.  The following code sets the previously added 
            '   user data short (31) and double (-52.2) at index 0 
            '   and 1, respectively:

            vcadd.SetCurrentEntityUserDataShort(0, 31)
            vcadd.SetCurrentEntityUserDataDouble(1, -52.2)
        End If

        ' return
        Return (True)

    End Function

End Class
