﻿' VB.NET to Get Entity Properties
'   lines starting with an apostrophe are comments
Public Class GetEntProp

    ' create Visual CADD object
    Shared WithEvents vcadd As New VCadd32.Automation

    Public Shared Function Run(ByVal str As String) As Integer

        '   used for messages
        Dim sz As String

        '   Optional - Save the current drawing settings:
        '       When working with entity properties, it is generally 
        '       desirable to maintain the current settings in a 
        '       temporary buffer and restore the information on 
        '       completion.  This allows the user to continue using 
        '       his original settings without unexpected changes.  
        '       The following code stores the settings into a 
        '       temporary buffer:

        vcadd.SaveSettings()

        '   Parse the list for the desired entity:
        '       The standard parsing structures presented in the 
        '       previous sections are generally used to move through 
        '       the entities or a selection and retrieve the 
        '       properties.  However, in order to retrieve property 
        '       information, an entity need only to be set as current 
        '       within the database.  This can done by the parsing 
        '       methods or directly if the entity handle is known.  
        '       The following code demonstrates setting the current 
        '       entity based on a known ID.  Typically, this ID is 
        '       found through another parsing method.  This example 
        '       sets the current entity as number 0, the first entity 
        '       in the database:

        vcadd.SetCurrentEntity(0)

        '   Optional first method - Match the entity properties in 
        '   the settings and use a settings retrieval routine:
        '       This method requires the application to match all the 
        '       entity properties and set them as the drawing 
        '       settings in the user interface.  Typically, when 
        '       using this method, it is good practice to save the 
        '       current user settings prior to processing and then 
        '       return them on exit.  The following code matches the 
        '       current entity properties and retrieves the color 
        '       index corresponding to the entity property:

        vcadd.MatchCurrentEntity()

        '   for example, retrieve the color index of the current 
        '   entity
        Dim iColor As Short
        iColor = vcadd.GetColorIndex()

        '   Optional second method - Use a current entity routine to 
        '   get the desired property:
        '       The second method does not require the application to 
        '       retrieve the all entity properties into the drawing 
        '       settings.  The information can be retrieved directly 
        '       from the entity property settings.  The following 
        '       code retrieves the color setting directly from the 
        '       entity property:

        iColor = vcadd.GetCurrentEntityColor()

        '   Optional - Restore the settings:
        '       When working with entity properties it is generally 
        '       desirable to maintain the current set settings in a 
        '       temporary buffer and restore the information on 
        '       completion.  The following code restores the settings 
        '       from the temporary buffer:

        vcadd.RestoreSettings()

        sz = "First entity color index: " + CStr(iColor)
        MsgBox(sz, MsgBoxStyle.Information, "API Help Sample")

        ' return
        Return (True)

    End Function

End Class
