﻿' VB.NET to Parse a Selection
'   lines starting with an apostrophe are comments
Public Class ParseSelect

    ' create Visual CADD object
    Shared WithEvents vcadd As New VCadd32.Automation

    Public Shared Function Run(ByVal str As String) As Integer

        '   used for messages
        Dim sz As String

        '  Parse through the selection in the database:
        '      A selection is often what the user has selected 
        '      before he starts your tool and the selection is the 
        '      target of the tool for making some modification or 
        '      creating new entities.  In this example, since we 
        '      want it to run self-contained, we will also 
        '      illustrate how to create filtered selections in code.  
        '      The filtering method works with a specialized 
        '      selection filter.

        '  Optional - because we are going to construct our own 
        '  selection using code, we can start by de-selecting any 
        '  existing selection.

        vcadd.DeSelectAll()

        '  Optional - Turn selection highlight off:
        '      Because our tool will be selecting entities, we can 
        '      turn off the selection highlight to avoid the time 
        '      required to redraw the selected entities.  Or we may 
        '      choose to not display the selections to the user.  
        '      The following code turns the selection highlight off:

        vcadd.SetHighlight(0)

        '  Optional - Reset the filter:
        '      The application should reset the filter to clear out 
        '      any existing filter information.  By resetting the 
        '      filter an application is assured no other information 
        '      in either the user settings or an application 
        '      settings are used.  The following code resets the 
        '      selection filter:

        vcadd.FilterReset()

        '  Set the new filter criteria:
        '      The filter can be applied on a variety of entity 
        '      types, names, colors, layers, and widths.  You can 
        '      use any combination of these filter settings.  The 
        '      entity type IDs are presented in the topic Entity 
        '      Types.  The following example demonstrates a filter 
        '      for continuous lines using the SOLID line type 
        '      (index 0):

        vcadd.SetFilterKind(CONTINUOUSLINE2D)
        vcadd.SetFilterLineType(0)

        '  Set the filter active:

        vcadd.SetFilterActive(1)

        '  Select the entities:
        '      Since the filter has been set to select specific 
        '      types of entities and/or properties, when you select 
        '      any entities in the database, only those that meet 
        '      the filter criteria will be selected.  The following 
        '      code selects all entities through code:

        vcadd.SelectAll()

        '  Parse the filtered selection:
        '      After setting the filtered selection list in code, or 
        '      optionally processing a selection from the user, 
        '      specialized parsing procedures are available to move 
        '      through the selected entities in the database.  
        '      These parsing routines are analogous to the standard 
        '      parsing routines.  The following code parses through 
        '      the selection list:

        '  setup a counter
        Dim iCount As Integer = 0

        '  start at the first selected entity
        vcadd.FirstSelected()

        Do While (vcadd.GetErrorCode() = 0)
            '  your tool would do whatever processing is required
            '      for example, count the un-erased lines
            If (vcadd.IsCurrentErased() = 0) Then
                iCount = iCount + 1
            End If

            vcadd.NextSelected()
        Loop

        '  De-select the entities:
        '      The selection list should be cleared after the 
        '      processing has finished.  The following code 
        '      de-selects all the entities in the drawing:

        vcadd.DeSelectAll()

        '  Turn the filter off:

        vcadd.SetFilterActive(0)

        '  Optional: Reset the filter:
        '      The filter should be reset after the operation to 
        '      clean up any filter criteria which might appear in 
        '      the user interface.  The following code resets the selection filter:

        vcadd.FilterReset()

        '  Optional: Turn the highlight display on:
        '      The following code turns the selection highlight on:

        vcadd.SetHighlight(1)

        sz = "SOLID continuous line count: " + CStr(iCount)
        MsgBox(sz, MsgBoxStyle.Information, "API Help Sample")

        ' return
        Return (True)

    End Function

End Class
