﻿' VB.NET to Parse a Symbol
'   lines starting with an apostrophe are comments
Public Class ParseSym

    ' create Visual CADD object
    Shared WithEvents vcadd As New VCadd32.Automation

    Public Shared Function Run(ByVal str As String) As Integer

        '   used for messages
        Dim sz As String

        '   Set the symbol section for parsing:
        '       When querying information about entities, it is 
        '       necessary to parse the database for the desired item 
        '       and set it as the current handle.  Symbols behave as 
        '       other "primitive" entities that are present within 
        '       the drawing database.  In order to access information 
        '       about these sub-entities in a symbol, an application 
        '       needs to set the parsing selection to the symbol 
        '       definition prior to using the database routines.  
        '       This allows an application to retrieve and set values
        '       pertaining to entities within a symbol definition.
        '       The following code sets the parsing section for a 
        '       symbol name "InternalSymbolName":

        vcadd.SetSymbolSection("MySymbolDefintion")

        '   Error checking:
        '       If the requested symbol was not found, there can be 
        '       unpredictable results by proceeding as if it was 
        '       found.  So check the error and take appropriate 
        '       action:

        If (vcadd.GetErrorCode() <> 0) Then
            '   Error condition

            '   show the user a warning message
            sz = "MySymbolDefinition symbol not found"
            MsgBox(sz, MsgBoxStyle.Exclamation, "API Help Sample")
        Else
            '   Success condition

            '   Use the database parsing routines:
            '       When querying information from a symbol definition, 
            '       it is necessary to parse within the definition to 
            '       retrieve the properties.  Any of the parsing methods 
            '       provided through the API may be used.  The following 
            '       code uses a loop to parse the symbol entity and 
            '       returns a count for the number of entities in that 
            '       symbol:

            Dim iCount As Integer = 0   '   initialize to 0

            '   start at the first entity in the symbol definition
            vcadd.FirstEntity()

            '   loop through and count the entities  
            Do While (vcadd.GetErrorCode() = 0)
                iCount = iCount + 1
                vcadd.NextEntity()
            Loop

            sz = "MySymbolDefintion entity count: " + CStr(iCount)
            MsgBox(sz, MsgBoxStyle.Information, "API Help Sample")
        End If

        '   Reset the parsing routines to the entity section:
        '       After completion of the symbol parsing routine, reset 
        '       the entity section to the drawing.  Otherwise other 
        '       routines parsing the database might accidentally 
        '       parse the symbol rather than the database.  The 
        '       following code resets the parsing section to the 
        '       drawing:

        vcadd.SetEntitySection()

        ' return
        Return (True)

    End Function

End Class
